@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -41,6 +42,17 @@
 
 #define d(x)
 
+
+/**
+ * SECTION: gmime-part
+ * @title: GMimePart
+ * @short_description: MIME parts
+ * @see_also:
+ *
+ * A #GMimePart represents any MIME leaf part (meaning it has no
+ * sub-parts).
+ **/
+
 /* GObject class methods */
 static void g_mime_part_class_init (GMimePartClass *klass);
 static void g_mime_part_init (GMimePart *mime_part, GMimePartClass *klass);
@@ -79,7 +91,7 @@ g_mime_part_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimePart),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_part_init,
 		};
 		
@@ -429,12 +441,12 @@ mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * text/plain.
  **/
 GMimePart *
-g_mime_part_new ()
+g_mime_part_new (void)
 {
 	GMimePart *mime_part;
 	GMimeContentType *type;
 	
-	mime_part = g_object_new (GMIME_TYPE_PART, NULL, NULL);
+	mime_part = g_object_new (GMIME_TYPE_PART, NULL);
 	
 	type = g_mime_content_type_new ("text", "plain");
 	g_mime_object_set_content_type (GMIME_OBJECT (mime_part), type);
@@ -458,7 +470,7 @@ g_mime_part_new_with_type (const char *type, const char *subtype)
 	GMimePart *mime_part;
 	GMimeContentType *content_type;
 	
-	mime_part = g_object_new (GMIME_TYPE_PART, NULL, NULL);
+	mime_part = g_object_new (GMIME_TYPE_PART, NULL);
 	
 	content_type = g_mime_content_type_new (type, subtype);
 	g_mime_object_set_content_type (GMIME_OBJECT (mime_part), content_type);
@@ -764,6 +776,9 @@ g_mime_part_get_content_location (GMimePart *mime_part)
  * @mime_type: Mime content-type
  *
  * Set the content type/subtype for the specified mime part.
+ *
+ * WARNING: This interface is deprecated. Use
+ * g_mime_object_set_content_type().
  **/
 void
 g_mime_part_set_content_type (GMimePart *mime_part, GMimeContentType *mime_type)
@@ -782,6 +797,9 @@ g_mime_part_set_content_type (GMimePart *mime_part, GMimeContentType *mime_type)
  * Gets the Content-Type object for the given mime part or %NULL on
  * error.
  *
+ * WARNING: This interface is deprecated. Use
+ * g_mime_object_get_content_type().
+ *
  * Returns the content-type object for the specified mime part.
  **/
 const GMimeContentType *
@@ -900,6 +918,8 @@ g_mime_part_encoding_from_string (const char *encoding)
 		return GMIME_PART_ENCODING_BASE64;
 	else if (!g_ascii_strcasecmp (encoding, "quoted-printable"))
 		return GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+	else if (!g_ascii_strcasecmp (encoding, "uuencode"))
+		return GMIME_PART_ENCODING_UUENCODE;
 	else if (!g_ascii_strcasecmp (encoding, "x-uuencode"))
 		return GMIME_PART_ENCODING_UUENCODE;
 	else
